"use strict";

// Class Definition
var KTLoginGeneral = function() {

    var login = $('#kt_login');

    var showErrorMsg = function(form, type, msg) {
        var alert = $('<div class="kt-alert kt-alert--outline alert alert-' + type + ' alert-dismissible" role="alert">\
			<button type="button" class="close" data-dismiss="alert" aria-label="Close"></button>\
			<span></span>\
		</div>');

        form.find('.alert').remove();
        alert.prependTo(form);
        //alert.animateClass('fadeIn animated');
        KTUtil.animateClass(alert[0], 'fadeIn animated');
        alert.find('span').html(msg);
    }

    // Private Functions
    var displaySignUpForm = function() {
        login.removeClass('login--forgot');
        login.removeClass('login--signin');

        login.addClass('login--signup');
        KTUtil.animateClass(login.find('.login__signup')[0], 'flipInX animated');
    }

    var displaySignInForm = function() {
        login.removeClass('login--forgot');
        login.removeClass('login--signup');

        login.addClass('login--signin');
        KTUtil.animateClass(login.find('.login__signin')[0], 'flipInX animated');
        //login.find('.login__signin').animateClass('flipInX animated');
    }

    var displayForgotForm = function() {
        login.removeClass('login--signin');
        login.removeClass('login--signup');

        login.addClass('login--forgot');
        //login.find('.login--forgot').animateClass('flipInX animated');
        KTUtil.animateClass(login.find('.login__forgot')[0], 'flipInX animated');

    }

    if (window.location.href.indexOf('#reset') > 0) {
        displayForgotForm();
    } else {
        displaySignInForm();
    }
    var handleFormSwitch = function() {
        $('#kt_login_forgot').on('click', function(e) {
            e.preventDefault();
            displayForgotForm();
        });

        $('#kt_login_forgot_cancel').on('click', function(e) {
            e.preventDefault();
            displaySignInForm();
        });

        $('#kt_login_signup_cancel').on('click', function(e) {
            e.preventDefault();
            displaySignInForm();
        });
    }

    var handleSignInFormSubmit = function() {
        $('#kt_login_signin_submit').on('click', function(e) {
            e.preventDefault();
            var btn = $(this);
            var form = $(this).closest('form');           

            form.validate({
                rules: {
                    username: {
                        required: true,
                        minlength: 5,
                        maxlength: 36,
                    },
                    password: {
                        required: true,
                        minlength: 8,
                        maxlength: 120
                    }
                },
                messages: {
                    username: {
                        required: "Please specify your name",
                        minlength: "Username can not be less then 5 characters",
                        maxlength: "Username can not be more then 36 characters",
                    },
                    password: {
                        required: "Please enter you password",
                        minlength: "password can not be less then 8 characters",
                        maxlength: "password can not be more then 120 characters",
                    }
                }
            });

            if (!form.valid()) {
                return;
            }

            btn.addClass('kt-spinner kt-spinner--right kt-spinner--sm kt-spinner--light').attr('disabled', true);

            form.submit();
        });
    }

    var handleForgotFormSubmit = function() {
        $('#kt_login_forgot_submit').click(function(e) {
            e.preventDefault();

            var btn = $(this);
            var form = $(this).closest('form');

            form.validate({
                rules: {
                    user: {
                        required: true,
                        minlength: 5,
                        maxlength: 36
                    },
                    email: {
                        required: true,
                        email: true
                    }
                },
                messages: {
                    user: {
                        required: "Please specify your name",
                        minlength: "Username can not be less then 5 characters",
                        maxlength: "Username can not be more then 36 characters",
                    },
                    email: {
                        required: "We need your email address to contact you",
                        email: "Your email address must be in the format of name@domain.com"
                    }
                }
            });

            if (!form.valid()) {
                return;
            }

            btn.addClass('kt-spinner kt-spinner--right kt-spinner--sm kt-spinner--light').attr('disabled', true);

            form.submit();

        });
    }

    // Public Functions
    return {
        // public functions
        init: function() {
            handleFormSwitch();
            handleSignInFormSubmit();
            handleForgotFormSubmit();
        }
    };
}();

// Class Initialization
jQuery(document).ready(function() {
    KTLoginGeneral.init();
});