"use strict";
// Class definition
var compId = $('#compIdVal').val();

var KTAppUserListDatatable = function() {

	// variables
	var datatable;
	
	// init
	var init = function() {
		
		datatable = $('#mails_list_datatable').KTDatatable({
			// datasource definition
			data: {
				type: 'remote',
				source: {
					read: {
						url: `includes/mailsjsonddata.php`,
					},
				},
				pageSize: 300, // display 20 records per page
				serverPaging: true,
				serverFiltering: true,
				serverSorting: true,
			},

			// layout definition
			layout: {
				theme: 'default',
                class: '',
                height: 1200,
				scroll: true, // enable/disable datatable scroll both horizontal and vertical when needed.
				footer: false, // display/hide footer
			},
			// column sorting
			sortable: true,

			pagination: true,

			// columns definition
			columns: [
			{
				field: "mail_id",
				title: "#",
				sortable: false,
				width: 20,
				selector: {
					class: 'kt-checkbox--solid'
				},
				textAlign: 'left'
			},{
				field: "",
				title: 'mail website',
				width: 200,
				textAlign: 'left',
				sortable: false,
				template: function(row) {
					var NativeUrl = row.mail_url;
					try { 
						NativeUrl = decodeURIComponent(NativeUrl); 
					} catch(e) {  
					}
					NativeUrl = NativeUrl.replace(/"| +/g, '');
					return `<a class="btn btn-bold btn-sm btn-font-sm small slice-Text text-left" target="_blank" href="${NativeUrl}"> ${NativeUrl} </a>`;
				},
			},{
				field: 'email',
				title: 'email',
				width: 200,
				textAlign: 'left',
				sortable: false,
				template: function(row) {
					return `<h6 class="kt-font-info small"> ${row.mail_text} </h6>`;
				},
			},{
				field: 'Author',
				title: 'Author',
				width: 100,
				textAlign: 'left',
				sortable: false,
				template: function(row) {
					return `<h6 class="kt-font-info small"> ${row.mail_author} </h6>`;
				}
			},{
				field: 'mail_satate',
				title: 'email Status',
				width: 100,
				textAlign: 'left',
				sortable: false,
				template: function(row) {
					let status,
						btnState;
					if(row.mail_state == 1) {
						status = "completed";
						btnState = "btn-label-success";
					} else if(row.mail_state !== 1 ) {
						status = "Incompleted";
						btnState = "btn-label-warning";
					}
					return `
						<div class='btn-state'> 
							<button class="btn btn-bold btn-sm px-2 ${btnState}"> ${status} </button> 
						</div>
					`;
				},
			},{
				field: 'Domain Rating',
				title: 'Domain Rating',
				width: 100,
				textAlign: 'center',
				sortable: false,
				template: function(row) {
					return `
						<h6 class="kt-font-info"> ${row.domain_rating} </h6>
					`;
				},
			},{
				field: 'Referring Domains',
				title: 'Referring Domains',
				width: 100,
				textAlign: 'center',
				sortable: false,
				template: function(row) {
					return `
						<h6 class="kt-font-info"> ${row.referring_domains} </h6>
					`;
				},
			},{
				field: 'Traffic',
				title: 'Traffic',
				width: 100,
				textAlign: 'center',
				sortable: false,
				template: function(row) {
					return `
						<h6 class="kt-font-info"> ${row.traffic} </h6>
					`;
				},
			},{
				field: 'Traffic Value',
				title: 'Traffic Value',
				width: 100,
				textAlign: 'center',
				sortable: false,
				template: function(row) {
					return `
						<h6 class="kt-font-info"> ${row.traffic_value} </h6>
					`;
				},
			}
			// {
			// 	field: 'mail_date_added',
			// 	title: 'Date',
			// 	width: 100,
			// 	textAlign: 'center',
			// 	sortable: false,
			// 	template: function(row) {
			// 		return `<h6 class="kt-font-danger small"> ${row.mail_date_add} </h6>`;
			// 	},
			// }
			]
		});
	}

	// search
	var search = function() {
		$('#kt_form_status').on('change', function() {
			datatable.search($(this).val().toLowerCase(), 'Status');
		});
	}

	// selection
	var selection = function() {
		// init form controls
		$('#kt_form_status, #kt_form_type').selectpicker();

		// event handler on check and uncheck on records
		datatable.on('kt-datatable--on-check kt-datatable--on-uncheck kt-datatable--on-layout-updated',	function(e) {
			var checkedNodes = datatable.rows('.kt-datatable__row--active').nodes(); // get selected records
			var count = checkedNodes.length; // selected records count

			$('#kt_subheader_group_selected_rows').html(count);
				
			if (count > 0) {
				$('#kt_subheader_search').addClass('kt-hidden');
				$('#kt_subheader_group_actions').removeClass('kt-hidden');
			} else {
				$('#kt_subheader_search').removeClass('kt-hidden');
				$('#kt_subheader_group_actions').addClass('kt-hidden');
			}
		});
	}

	// selected records delete
	var selectedDelete = function() {
		$('#kt_subheader_group_actions_delete_all').on('click', function() {
			// fetch selected IDs
			var ids = datatable.rows('.kt-datatable__row--active').nodes().find('.kt-checkbox--single > [type="checkbox"]').map(function(i, chk) {
				return $(chk).val();
			});

			if (ids.length > 0) {
				swal.fire({
					buttonsStyling: false,

					text: "Are you sure to delete " + ids.length + " selected records ?",
					type: "danger",

					confirmButtonText: "Yes, delete!",
					confirmButtonClass: "btn btn-sm btn-bold btn-danger",

					showCancelButton: true,
					cancelButtonText: "No, cancel",
					cancelButtonClass: "btn btn-sm btn-bold btn-brand"
				}).then(function(result) {
					if (result.value) {
						swal.fire({
							title: 'Deleted!',
							text: 'Your selected records have been deleted! :(',
							type: 'success',
							buttonsStyling: false,
							confirmButtonText: "OK",
							confirmButtonClass: "btn btn-sm btn-bold btn-brand",
						})
						// result.dismiss can be 'cancel', 'overlay',
						// 'close', and 'timer'
					} else if (result.dismiss === 'cancel') {
						swal.fire({
							title: 'Cancelled',
							text: 'You selected records have not been deleted! :)',
							type: 'error',
							buttonsStyling: false,
							confirmButtonText: "OK",
							confirmButtonClass: "btn btn-sm btn-bold btn-brand",
						});
					}
				});
			}
		});		
	}

	var updateTotal = function() {
		datatable.on('kt-datatable--on-layout-updated', function () {
			$('#kt_subheader_total').html(datatable.getTotalRows() + ' Total');
		});
	};
	

	return {
		// public functions
		init: function() {
			init();
			// search();
			// selection();
			// selectedDelete();
			// updateTotal();
		},
	};
}();

// On document ready
KTUtil.ready(function() {
	KTAppUserListDatatable.init();
});
